summaryrefslogtreecommitdiffstats
path: root/shlibs/mount/src/context.c
diff options
context:
space:
mode:
authorKarel Zak2011-02-02 21:19:14 +0100
committerKarel Zak2011-02-02 21:19:14 +0100
commitcfb9db309558ca45c670947e1bf391152c662f1e (patch)
tree2e82ec6a65f1a446f2e63d5fbb7862f0d43f90aa /shlibs/mount/src/context.c
parentlibmount: copy mount attrs from utab to context (diff)
downloadkernel-qcow2-util-linux-cfb9db309558ca45c670947e1bf391152c662f1e.tar.gz
kernel-qcow2-util-linux-cfb9db309558ca45c670947e1bf391152c662f1e.tar.xz
kernel-qcow2-util-linux-cfb9db309558ca45c670947e1bf391152c662f1e.zip
libmount: cleanup high-level mount API
Signed-off-by: Karel Zak <kzak@redhat.com>
Diffstat (limited to 'shlibs/mount/src/context.c')
-rw-r--r--shlibs/mount/src/context.c4
1 files changed, 2 insertions, 2 deletions
diff --git a/shlibs/mount/src/context.c b/shlibs/mount/src/context.c
index 676552bf1..de852a3af 100644
--- a/shlibs/mount/src/context.c
+++ b/shlibs/mount/src/context.c
@@ -1486,7 +1486,7 @@ int mnt_context_get_status(struct libmnt_context *cxt)
* @status: mount(2) return code
*
* This function should be used if [u]mount(2) syscall was NOT called by
* libmount (mnt_mount_context() or mnt_context_do_mount()) only.
*
* Returns: 0 or negative number in case of error.
*/
@@ -1586,7 +1586,7 @@ int test_mount(struct libmnt_test *ts, int argc, char *argv[])
if (lock)
atexit(lock_fallback);
- rc = mnt_mount_context(cxt);
+ rc = mnt_context_mount(cxt);
if (rc)
printf("failed to mount %s\n", strerror(errno));
else
@@ -1486,7 +1486,7 @@ int mnt_context_get_status(struct libmnt_context *cxt)
*
* This function should be used if [u]mount(2) syscall was NOT called by
- * libmount (mnt_mount_context() or mnt_context_do_mount()) only.
+ * libmount (mnt_context_mount() or mnt_context_do_mount()) only.
*
* Returns: 0 or negative number in case of error.